# <img src='https://0000.us/klatchat/app/files/neon_images/icons/neon_skill.png' card_color="#FF8600" width="50" style="vertical-align:bottom">Messaging

## Summary

Handles mobile requests for phone calls, SMS, and emails.

## Description

This handles SMS, phone call, and email requests.

## Examples

Place Call:
- call Daniel
- call 555-555-5555

Send a Message:
- Send a text message to Daniel that says hello
- Send an email to demo@neongecko.com with the subject Test Email

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonDaniel](https://github.com/NeonDaniel)
[NeonGeckoCom](https://github.com/NeonGeckoCom)

## Tags
#NeonGecko Original
#NeonAI
#Communication
#SMS
#Email
#Phone
#Android